@@ -202,6 +202,7 @@ func TestRPMSpecific(t *testing.T) {
 	testNames := []string{
 		"release",
 		"directories",
+		"verify",
 	}
 	for _, name := range testNames {
 		for _, arch := range formatArchs[format] {
@@ -234,6 +235,7 @@ func TestDebSpecific(t *testing.T) {
 		"rules",
 		"triggers",
 		"breaks",
+		"predepends",
 	}
 	for _, name := range testNames {
 		for _, arch := range formatArchs[format] {
